@@ -11,6 +11,7 @@
 #include <glib/gstdio.h>
 #include <cstdio>
 #include <cerrno>
+#include <cstring>
 
 const int TITLE_COLUMN = 0;
 const int FILENAME_COLUMN = 1;
@@ -272,7 +273,7 @@ DemoWindow::find_file(const char *base, G::Error *error)
 		return base;
 	else
 	{
-		char *filename = g_build_filename(DEMOCODEDIR, base, 0);
+		char *filename = g_build_filename(DEMOCODEDIR, base, NULL);
 		if (!g_file_test(filename, G_FILE_TEST_EXISTS))
 		{
 			if (error)
@@ -409,8 +410,7 @@ read_line(FILE *stream, GString *str)
 	return n_read > 0;
 }
 
-void
-parse_chars(char *text, char **end_ptr, int *state, char **tag, bool start)
+void parse_chars(char *text, char **end_ptr, int *state, char **tag, bool start)
 {
 	while (g_ascii_isspace(*text))
 				text++;
