@@ -37,12 +37,11 @@ GError* error_new_valist(GQuark domain, int code, const char *format, va_list ar
 
 } // namespace
 
-G::Error::Error()
-: error_(0)
+G::Error::Error() throw() : error_(0)
 {
 }
 
-G::Error::Error(GQuark domain, int code, const char *format, ...)
+G::Error::Error(GQuark domain, int code, const char *format, ...) throw()
 : error_(0)
 {
 	g_return_if_fail(format != 0);
@@ -53,22 +52,22 @@ G::Error::Error(GQuark domain, int code, const char *format, ...)
 	va_end(args);
 }
 
-G::Error::Error(GQuark domain, int code, const String& message)
+G::Error::Error(GQuark domain, int code, const String& message) throw()
 : error_(g_error_new_literal(domain, code, message.c_str()))
 {
 }
 
-G::Error::Error(GError *error)
+G::Error::Error(GError *error) throw()
 : error_(g_error_copy(error))
 {
 }
 
-G::Error::Error(const Error& src)
+G::Error::Error(const Error& src) throw()
 : error_(g_error_copy(src.error_))
 {
 }
 
-G::Error::~Error()
+G::Error::~Error() throw()
 {
 	if (error_)
 	{
@@ -124,3 +123,7 @@ G::Error::propagate(const Error& src)
 	g_propagate_error(&error_, src.error_);
 }
 
+const char * G::Error::what( void ) const throw()
+{
+    return (error_) ? error_->message : "Undefined error";
+}
