@@ -223,7 +223,7 @@ G::find_program_in_path(const std::string& program)
 std::string 
 G::build_filename(const std::string& s1, const std::string& s2)
 {
-	char *result = g_build_filename(s1.c_str(), s2.c_str(), 0);
+	char *result = g_build_filename(s1.c_str(), s2.c_str(), NULL);
 	std::string s(result);
 	g_free(result);
 	return s;
@@ -232,7 +232,7 @@ G::build_filename(const std::string& s1, const std::string& s2)
 std::string 
 G::build_filename(const std::string& s1, const std::string& s2, const std::string& s3)
 {
-	char *result = g_build_filename(s1.c_str(), s2.c_str(), s3.c_str(), 0);
+	char *result = g_build_filename(s1.c_str(), s2.c_str(), s3.c_str(), NULL);
 	std::string s(result);
 	g_free(result);
 	return s;
@@ -241,7 +241,7 @@ G::build_filename(const std::string& s1, const std::string& s2, const std::strin
 std::string 
 G::build_filename(const std::string& s1, const std::string& s2, const std::string& s3, const std::string& s4)
 {
-	char *result = g_build_filename(s1.c_str(), s2.c_str(), s3.c_str(), s4.c_str(), 0);
+	char *result = g_build_filename(s1.c_str(), s2.c_str(), s3.c_str(), s4.c_str(), NULL);
 	std::string s(result);
 	g_free(result);
 	return s;
@@ -253,7 +253,7 @@ G::build_filename(const std::string& s1, const std::string& s2, const std::strin
 std::string 
 G::build_path(const std::string& separator, const std::string& s1, const std::string& s2)
 {
-	char *result = g_build_path(separator.c_str(), s1.c_str(), s2.c_str(), 0);
+	char *result = g_build_path(separator.c_str(), s1.c_str(), s2.c_str(), NULL);
 	std::string s(result);
 	g_free(result);
 	return s;
@@ -262,7 +262,7 @@ G::build_path(const std::string& separator, const std::string& s1, const std::st
 std::string 
 G::build_path(const std::string& separator, const std::string& s1, const std::string& s2, const std::string& s3)
 {
-	char *result = g_build_path(separator.c_str(), s1.c_str(), s2.c_str(), s3.c_str(), 0);
+	char *result = g_build_path(separator.c_str(), s1.c_str(), s2.c_str(), s3.c_str(), NULL);
 	std::string s(result);
 	g_free(result);
 	return s;
@@ -271,7 +271,7 @@ G::build_path(const std::string& separator, const std::string& s1, const std::st
 std::string 
 G::build_path(const std::string& separator, const std::string& s1, const std::string& s2, const std::string& s3, const std::string& s4)
 {
-	char *result = g_build_path(separator.c_str(), s1.c_str(), s2.c_str(), s3.c_str(), s4.c_str(), 0);
+	char *result = g_build_path(separator.c_str(), s1.c_str(), s2.c_str(), s3.c_str(), s4.c_str(), NULL);
 	std::string s(result);
 	g_free(result);
 	return s;
