@@ -25,6 +25,7 @@
 #include <glib/gmessages.h>
 #include <glib/gshell.h>
 #include <glib/gstrfuncs.h>
+#include <cstring>
 
 extern char **environ;
 
@@ -85,7 +86,7 @@ make_environment_for_screen(GdkScreen *screen, char **envp)
 	for (i = 0; i < env_len; i++)
 	{
 		if (i == display_index)
-			retval[i] = g_strconcat("DISPLAY=", display_name, 0);
+			retval[i] = g_strconcat("DISPLAY=", display_name, NULL);
 		else
 			retval[i] = g_strdup(envp[i]);
 	}
