@@ -3,19 +3,19 @@
  *
  *  marshal.cc - GObject signal callback functions.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Lesser General Public
+ *  License as published by the Free Software Foundation; either
+ *  version 2 of the License, or (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with this library; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
  */
 
 #include "private/marshal.hh"
@@ -312,6 +312,21 @@ Gtk::Marshal::void_uint_string_callback(void *data, unsigned int arg1, const cha
 	}
 }
 
+/*  Gtk::Marshal::void_textiter_callback
+ */
+
+void Gtk::Marshal::void_textiter_callback( void *data, GtkTextIter *arg1 )
+{
+	G::Connection *c = static_cast<G::Connection*>(data);
+	if (c)
+	{
+		typedef	sigc::slot<void, TextIter&> SlotType;
+		SlotType& slot = static_cast<SlotType&>(c->slot_);
+		TextIter iter(arg1);
+		slot(iter);
+	}
+}
+
 /*  Gtk::Marshal::void_textiter_string_int_callback
  */
 
